@@ -2,12 +2,13 @@ package Egg::Plugin::EasyDBI;
 #
 # Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id: EasyDBI.pm 302 2008-03-05 07:45:10Z lushe $
+# $Id: EasyDBI.pm 312 2008-04-16 19:22:56Z lushe $
 #
 use strict;
 use warnings;
+use Time::Piece::MySQL;
 
-our $VERSION= '3.01';
+our $VERSION= '3.02';
 
 sub _setup {
 	my($e)= @_;
@@ -24,6 +25,11 @@ sub dbh {
 sub db {
 	shift->dbh(@_)->db;
 }
+sub mysql_datetime {
+	my $self= shift;
+	my $Time= shift || time;
+	localtime($Time)->mysql_datetime
+}
 sub close_dbh {
 	my $e= shift;
 	my $rollback= $_[0] ? sub {}: sub { $_[0]->rollback_ok(1) };
@@ -183,6 +189,16 @@ When tables unite, it becomes the following.
 
 see L<Egg::Mod::EasyDBI>.
 
+=head2 mysql_datetime ([TIME])
+
+The time value is received and the character string of the datetime type is 
+returned.
+
+When TIME is omitted, a present time value is used.
+
+  # It was timely the day before of the 30th.
+  my $datetime= $e->mysql_datetime( time- (30* 24* 60* 60) );
+
 =head2 close_dbh ([BOOL])
 
 All the opened transactions are shut and the object is annulled.
